//----------------------------------------------------------------------
// GTK - The GIMP Toolkit
//
// Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
// Copyright (C) 2002 Gran Hasse, Raditex, gorhas@raditex.nu
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
//----------------------------------------------------------------------

static volatile char idtxt_h[] = "Version 0.1";

#ifndef __GTK_HHBAR_H__
#define __GTK_HHBAR_H__

#include <gdk/gdk.h>
#include <gtk/gtkadjustment.h>
#include <gtk/gtkwidget.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define GTK_HHBAR(obj)          GTK_CHECK_CAST (obj, gtk_hhbar_get_type (), GtkHHbar)
#define GTK_HHBAR_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gtk_hhbar_get_type (), GtkHHbarClass)
#define GTK_IS_HHBAR(obj)       GTK_CHECK_TYPE (obj, gtk_hhbar_get_type ())

typedef struct _GtkHHbar        GtkHHbar;
typedef struct _GtkHHbarClass   GtkHHbarClass;

struct _GtkHHbar
{
    GtkWidget widget;

    /* update policy (GTK_UPDATE_[CONTINUOUS/DELAYED/DISCONTINUOUS]) */
    guint policy : 2;

    /* Button currently pressed or 0 if none */
    guint8 button;

    /* Dimensions of HHbar components */
    gint width;
    gint height;
    gint handle_width;

    gint x_delta;

    /* ID of update timer, or 0 if none */
    guint32 timer;

    /* Current angle */
    gfloat value;
    gfloat last_pos;

    /* Old values from adjustment stored so we know when something changes */
    gfloat old_value;
    gfloat old_lower;
    gfloat old_upper;

    /* The adjustment object that stores the data for this Therm */
    GtkAdjustment *adjustment;
    
};

struct _GtkHHbarClass
{
    GtkWidgetClass parent_class;
};


GtkWidget*     gtk_hhbar_new                    (GtkAdjustment *adjustment);
guint          gtk_hhbar_get_type               (void);
GtkAdjustment* gtk_hhbar_get_adjustment         (GtkHHbar      *hhbar);
void           gtk_hhbar_set_update_policy      (GtkHHbar      *hhbar,
						  GtkUpdateType  policy);
void           gtk_hhbar_set_adjustment         (GtkHHbar      *hhbar,
						  GtkAdjustment *adjustment);

void gtk_hhbar_on(GtkHHbar *hhbar, gboolean state, gboolean gate);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_HHBAR_H__ */
